import { XrplNetwork } from 'xpring-common-js';
import PayIdClient from './pay-id-client';
import XrpPayIdClientInterface from './xrp-pay-id-client-interface';
/**
 * Provides functionality for XRP in the PayID protocol.
 */
export default class XrpPayIdClient extends PayIdClient implements XrpPayIdClientInterface {
    readonly xrplNetwork: XrplNetwork;
    /**
     * @param xrplNetwork The XRP Ledger network that this client attaches to.
     * @param useHttps Whether to use HTTPS when making PayID requests. Most users should set this to 'true' to avoid
     *                 Man-in-the-Middle attacks. Exposed as an option for testing purposes. Defaults to true.
     */
    constructor(xrplNetwork: XrplNetwork, useHttps?: boolean);
    /**
     * Retrieve the XRP address associated with a PayID.
     *
     * Note: Addresses are always in the X-Address format.
     * @see https://xrpaddress.info/
     *
     * @param payId The PayID to resolve for an address.
     * @returns An XRP address representing the given PayID.
     */
    xrpAddressForPayId(payId: string): Promise<string>;
}
