import { AccountLinesResponse } from '../shared/rippled-json-rpc-schema';
/**
 * A network client for interacting with the rippled JSON RPC.
 * @see https://xrpl.org/rippled-api.html
 */
export default class JsonRpcNetworkClient {
    private readonly axiosInstance;
    /**
     * Create a new JsonRpcNetworkClient.
     *
     * @param jsonUrl The URL of the rippled node to query.
     * @see https://xrpl.org/get-started-with-the-rippled-api.html
     */
    constructor(jsonUrl: string);
    /**
     * Submit a JSON request to the rippled server.
     *
     * @param jsonRequest A JSON object specifying the method and params of the request.
     * @see https://xrpl.org/request-formatting.html#json-rpc-format
     * @returns The response from the rippled server.
     */
    private submitRequest;
    /**
     * Submits an account_lines request to the rippled JSON RPC.
     *
     * @param account The XRPL account to query for trust lines.
     */
    getAccountLines(account: string): Promise<AccountLinesResponse>;
}
