import { XrplNetwork } from 'xpring-common-js';
import { AccountDelete } from '../Generated/web/org/xrpl/rpc/v1/transaction_pb';
export default class XrpAccountDelete {
    readonly destinationXAddress: string;
    /**
     * Constructs an XrpAccountDelete from an AccountDelete protocol buffer.
     *
     * @param accountDelete an AccountDelete (protobuf object) whose field values will be used
     *                to construct an XrpAccountDelete
     * @return an XrpAccountDelete with its fields set via the analogous protobuf fields.
     * @see https://github.com/ripple/rippled/blob/3d86b49dae8173344b39deb75e53170a9b6c5284/src/ripple/proto/org/xrpl/rpc/v1/transaction.proto#L118
     */
    static from(accountDelete: AccountDelete, xrplNetwork: XrplNetwork): XrpAccountDelete;
    /**
     * @param destinationXAddress The address and destination tag of an account to receive any leftover XRP after deleting the
     *                            sending account, encoded as an X-address (see https://xrpaddress.info/).
     *                            Must be a funded account in the ledger, and must not be the sending account.
     */
    private constructor();
}
