import { CurrencyAmount } from '../Generated/web/org/xrpl/rpc/v1/amount_pb';
import XrpIssuedCurrency from './xrp-issued-currency';
/**
 * An amount of currency on the XRP Ledger
 * @see: https://xrpl.org/basic-data-types.html#specifying-currency-amounts
 */
export default class XrpCurrencyAmount {
    readonly drops?: string | undefined;
    readonly issuedCurrency?: XrpIssuedCurrency | undefined;
    /**
     * Constructs an XrpCurrencyAmount from a CurrencyAmount.
     *
     * @param currencyAmount a CurrencyAmount (protobuf object) whose field values will be used
     *                       to construct an XrpCurrencyAmount
     * @returns an XrpCurrencyAmount with its fields set via the analogous protobuf fields.
     * @see https://github.com/ripple/rippled/blob/develop/src/ripple/proto/org/xrpl/rpc/v1/amount.proto#L10
     */
    static from(currencyAmount: CurrencyAmount): XrpCurrencyAmount;
    /**
     * Note: Mutually exclusive fields - only drops XOR issuedCurrency should be set.
     *
     * @param drops An amount of XRP, specified in drops.
     * @param issuedCurrency An amount of an issued currency.
     */
    private constructor();
}
