import { XrplNetwork } from 'xpring-common-js';
import { EscrowCancel } from '../Generated/web/org/xrpl/rpc/v1/transaction_pb';
export default class XrpEscrowCancel {
    readonly ownerXAddress: string;
    readonly offerSequence: number;
    /**
     * Constructs an XrpEscrowCancel from an EscrowCancel protocol buffer.
     *
     * @param escrowCancel an EscrowCancel (protobuf object) whose field values will be used to construct an XrpEscrowCancel
     * @return an XrpEscrowCancel with its fields set via the analogous protobuf fields.
     * @see https://github.com/ripple/rippled/blob/3d86b49dae8173344b39deb75e53170a9b6c5284/src/ripple/proto/org/xrpl/rpc/v1/transaction.proto#L170
     */
    static from(escrowCancel: EscrowCancel, xrplNetwork: XrplNetwork): XrpEscrowCancel;
    /**
     * @param ownerXAddress Address of the source account that funded the escrow payment, encoded as an X-address (see https://xrpaddress.info/).
     * @param offerSequence Transaction sequence of EscrowCreate transaction that created the escrow to cancel.
     */
    private constructor();
}
