import { BigInteger } from 'big-integer';
import { IssuedCurrencyAmount } from '../Generated/web/org/xrpl/rpc/v1/amount_pb';
import XrpCurrency from './xrp-currency';
export default class XrpIssuedCurrency {
    readonly currency: XrpCurrency;
    readonly value: BigInteger;
    readonly issuer: string;
    /**
     * Constructs an XrpIssuedCurrency from an IssuedCurrencyAmount.
     *
     * @param issuedCurrency an IssuedCurrencyAmount (protobuf object) whose field values will be used
     *                       to construct an XrpIssuedCurrency
     * @returns an XrpIssuedCurrency with its fields set via the analogous protobuf fields.
     * @see https://github.com/ripple/rippled/blob/develop/src/ripple/proto/org/xrpl/rpc/v1/amount.proto#L28
     */
    static from(issuedCurrency: IssuedCurrencyAmount): XrpIssuedCurrency;
    /**
     * @param currency The currency used to value the amount.
     * @param value The value of the amount.
     * @param issuer Unique account address of the entity issuing the currency.
     */
    private constructor();
}
