import { Memo } from '../Generated/web/org/xrpl/rpc/v1/transaction_pb';
/**
 * Provides a means of passing a string to a memo that allows for user
 * specification as to whether or not the string is already a hex string.
 */
export interface MemoField {
    value?: string;
    isHex?: boolean;
}
export default class XrpMemo {
    readonly data?: Uint8Array | undefined;
    readonly format?: Uint8Array | undefined;
    readonly type?: Uint8Array | undefined;
    /**
     * Constructs an XrpMemo from a Memo.
     *
     * @param memo a Memo (protobuf object) whose field values will be used
     *              to construct an XrpMemo
     * @return an XrpMemo with its fields set via the analogous protobuf fields.
     * @see https://github.com/ripple/rippled/blob/develop/src/ripple/proto/org/xrpl/rpc/v1/transaction.proto#L80
     */
    static from(memo: Memo): XrpMemo;
    /**
     * Converts strings that may or may not be hex (as indicated by the MemoField argument) into the
     * Uint8Array fields needed for an XrpMemo instance.
     *
     * @param data - a MemoField with an optional string which may or may not be converted to a hex string.
     * @param format - a MemoField with an optional string which may or may not be converted to a hex string.
     * @param type - a MemoField with an optional string which may or may not be converted to a hex string.
     * @returns an XrpMemo with each potentially hex-encoded field set to the Uint8Array version of said field.
     */
    static fromMemoFields(data?: MemoField, format?: MemoField, type?: MemoField): XrpMemo;
    /**
     * @param data Arbitrary hex value, conventionally containing the content of the memo.
     * @param format Hex value representing characters allowed in URLs.  Conventionally containing
     *               information on how the memo is encoded, for example as a MIME type.
     * @param type Hex value representing characters allowed in URLs. Conventionally, a unique
     *               relation (according to RFC 5988) that defines the format of this memo.
     */
    private constructor();
}
