import { OfferCreate } from '../Generated/web/org/xrpl/rpc/v1/transaction_pb';
import XrpCurrencyAmount from './xrp-currency-amount';
export default class XrpOfferCreate {
    readonly takerGets: XrpCurrencyAmount;
    readonly takerPays: XrpCurrencyAmount;
    readonly expiration?: number | undefined;
    readonly offerSequence?: number | undefined;
    /**
     * Constructs an XrpOfferCreate from an OfferCreate protocol buffer.
     *
     * @param offerCreate an OfferCreate (protobuf object) whose field values will be used to construct an XrpOfferCreate
     * @return an XrpOfferCreate with its fields set via the analogous protobuf fields.
     * @see https://github.com/ripple/rippled/blob/3d86b49dae8173344b39deb75e53170a9b6c5284/src/ripple/proto/org/xrpl/rpc/v1/transaction.proto#L212
     */
    static from(offerCreate: OfferCreate): XrpOfferCreate;
    /**
     * @param takerGets The amount and type of currency being provided by the offer creator.
     * @param takerPays The amount and type of currency being requested by the offer creator.
     * @param expiration (Optional) Time after which the offer is no longer active, in seconds since the Ripple Epoch.
     * @param offerSequence (Optional) An offer to delete first, specified in the same way as OfferCancel.
     */
    private constructor();
}
