"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const xrp_path_element_1 = __importDefault(require("./xrp-path-element"));
/*
 * A path in the XRP Ledger.
 * @see: https://xrpl.org/paths.html
 */
class XrpPath {
    /**
     *
     * @param pathElements List of XrpPathElements that make up this XRPPath.
     */
    constructor(pathElements) {
        this.pathElements = pathElements;
    }
    /**
     * Constructs an XrpPath from a Path.
     *
     * @param path a Path (protobuf object) whose field values will be used
     *             to construct an XrpPath
     * @returns an XrpPath with its fields set via the analogous protobuf fields.
     * @see https://github.com/ripple/rippled/blob/develop/src/ripple/proto/org/xrpl/rpc/v1/transaction.proto#L237
     */
    static from(path) {
        const pathElements = path
            .getElementsList()
            .map((pathElement) => xrp_path_element_1.default.from(pathElement));
        return new XrpPath(pathElements);
    }
}
exports.default = XrpPath;
//# sourceMappingURL=xrp-path.js.map