import { SignerEntry } from '../Generated/web/org/xrpl/rpc/v1/common_pb';
import { XrplNetwork } from 'xpring-common-js';
export default class XrpSignerEntry {
    readonly accountXAddress: string;
    readonly signerWeight: number;
    /**
     * Constructs an XrpSignerEntry from a SignerEntry protocol buffer.
     *
     * @param signerEntry a SignerEntry (protobuf object) whose field values will be used to construct an XrpSignerEntry
     * @return an XrpSignerEntry with its fields set via the analogous protobuf fields.
     * @see https://github.com/ripple/rippled/blob/f43aeda49c5362dc83c66507cae2ec71cfa7bfdf/src/ripple/proto/org/xrpl/rpc/v1/common.proto#L471
     */
    static from(signerEntry: SignerEntry, xrplNetwork: XrplNetwork): XrpSignerEntry;
    /**
     * @param account An XRP Ledger address whose signature contributes to the multi-signature, encoded as an
     *                X-address (see https://xrpaddress.info/). It does not need to be a funded address in the ledger.
     * @param signerWeight The weight of a signature from this signer. A multi-signature is only valid if the sum
     *                     weight of the signatures provided meets or exceeds the SignerList's SignerQuorum value.
     */
    private constructor();
}
