/**
 * Types of errors that originate from Xpring.
 */
export declare enum XpringErrorType {
    MismatchedNetworks = 0,
    Unknown = 1
}
/**
 * Represents errors thrown by Xpring components of the Xpring SDK.
 */
export default class XpringError extends Error {
    readonly errorType: XpringErrorType;
    /**
     * Input entities given to a Xpring component were attached to different networks.
     *
     * For instance, this error may be thrown if a XpringClient was constructed with
     * a PayIDClient attached to Testnet and an XrpClient attached to Mainnet.
     */
    static mismatchedNetworks: XpringError;
    /**
     * @param errorType The type of error.
     * @param message The error message.
     */
    constructor(errorType: XpringErrorType, message?: string | undefined);
}
