"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.XpringErrorType = void 0;
/**
 * Types of errors that originate from Xpring.
 */
var XpringErrorType;
(function (XpringErrorType) {
    XpringErrorType[XpringErrorType["MismatchedNetworks"] = 0] = "MismatchedNetworks";
    XpringErrorType[XpringErrorType["Unknown"] = 1] = "Unknown";
})(XpringErrorType = exports.XpringErrorType || (exports.XpringErrorType = {}));
/**
 * Represents errors thrown by Xpring components of the Xpring SDK.
 */
class XpringError extends Error {
    /**
     * @param errorType The type of error.
     * @param message The error message.
     */
    constructor(errorType, message = undefined) {
        super(message);
        this.errorType = errorType;
    }
}
exports.default = XpringError;
/**
 * Input entities given to a Xpring component were attached to different networks.
 *
 * For instance, this error may be thrown if a XpringClient was constructed with
 * a PayIDClient attached to Testnet and an XrpClient attached to Mainnet.
 */
XpringError.mismatchedNetworks = new XpringError(XpringErrorType.MismatchedNetworks, 'Components are not connecting to the same network.');
//# sourceMappingURL=xpring-error.js.map